Raw Streams
===========

.. currentmodule:: sounddevice

.. autosummary::
   :nosignatures:

   RawStream
   RawInputStream
   RawOutputStream

.. autoclass:: RawStream
   :members: read, write

.. autoclass:: RawInputStream

.. autoclass:: RawOutputStream
